/****************************************************************************
** Meta object code from reading C++ file 'formats.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kcoreaddons-6.29.0/src/qml/formats.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'formats.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7FormatsE_t {};
} // unnamed namespace

template <> constexpr inline auto Formats::qt_create_metaobjectdata<qt_meta_tag_ZN7FormatsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Formats",
        "QML.Element",
        "Format",
        "QML.Singleton",
        "true",
        "formatByteSize",
        "",
        "size",
        "precision",
        "formatDuration",
        "msecs",
        "KFormat::DurationFormatOptions",
        "options",
        "formatDecimalDuration",
        "decimalPlaces",
        "formatSpelloutDuration",
        "formatRelativeDate",
        "date",
        "QLocale::FormatType",
        "format",
        "formatRelativeDateTime",
        "dateTime",
        "formatTime",
        "QVariant",
        "obj",
        "propertyName",
        "KFormat::TimeFormatOptions",
        "formatDistance",
        "distance",
        "KFormat::DistanceFormatOptions"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'formatByteSize'
        QtMocHelpers::MethodData<QString(double, int) const>(5, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Double, 7 }, { QMetaType::Int, 8 },
        }}),
        // Method 'formatByteSize'
        QtMocHelpers::MethodData<QString(double) const>(5, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::Double, 7 },
        }}),
        // Method 'formatDuration'
        QtMocHelpers::MethodData<QString(quint64, KFormat::DurationFormatOptions) const>(9, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::ULongLong, 10 }, { 0x80000000 | 11, 12 },
        }}),
        // Method 'formatDuration'
        QtMocHelpers::MethodData<QString(quint64) const>(9, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::ULongLong, 10 },
        }}),
        // Method 'formatDecimalDuration'
        QtMocHelpers::MethodData<QString(quint64, int) const>(13, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::ULongLong, 10 }, { QMetaType::Int, 14 },
        }}),
        // Method 'formatDecimalDuration'
        QtMocHelpers::MethodData<QString(quint64) const>(13, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::ULongLong, 10 },
        }}),
        // Method 'formatSpelloutDuration'
        QtMocHelpers::MethodData<QString(quint64) const>(15, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::ULongLong, 10 },
        }}),
        // Method 'formatRelativeDate'
        QtMocHelpers::MethodData<QString(const QDate &, QLocale::FormatType) const>(16, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QDate, 17 }, { 0x80000000 | 18, 19 },
        }}),
        // Method 'formatRelativeDateTime'
        QtMocHelpers::MethodData<QString(const QDateTime &, QLocale::FormatType) const>(20, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QDateTime, 21 }, { 0x80000000 | 18, 19 },
        }}),
        // Method 'formatTime'
        QtMocHelpers::MethodData<QString(const QVariant &, const QString &, QLocale::FormatType, KFormat::TimeFormatOptions) const>(22, 6, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 23, 24 }, { QMetaType::QString, 25 }, { 0x80000000 | 18, 19 }, { 0x80000000 | 26, 12 },
        }}),
        // Method 'formatTime'
        QtMocHelpers::MethodData<QString(const QVariant &, const QString &, QLocale::FormatType) const>(22, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { 0x80000000 | 23, 24 }, { QMetaType::QString, 25 }, { 0x80000000 | 18, 19 },
        }}),
        // Method 'formatTime'
        QtMocHelpers::MethodData<QString(const QVariant &, const QString &) const>(22, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { 0x80000000 | 23, 24 }, { QMetaType::QString, 25 },
        }}),
        // Method 'formatDistance'
        QtMocHelpers::MethodData<QString(double, KFormat::DistanceFormatOptions) const>(27, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Double, 28 }, { 0x80000000 | 29, 12 },
        }}),
        // Method 'formatDistance'
        QtMocHelpers::MethodData<QString(double) const>(27, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QString, {{
            { QMetaType::Double, 28 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<Formats, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Formats::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7FormatsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7FormatsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7FormatsE_t>.metaTypes,
    nullptr
} };

void Formats::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Formats *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->formatByteSize((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 1: { QString _r = _t->formatByteSize((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 2: { QString _r = _t->formatDuration((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KFormat::DurationFormatOptions>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->formatDuration((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->formatDecimalDuration((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { QString _r = _t->formatDecimalDuration((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { QString _r = _t->formatSpelloutDuration((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 7: { QString _r = _t->formatRelativeDate((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QLocale::FormatType>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 8: { QString _r = _t->formatRelativeDateTime((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QLocale::FormatType>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 9: { QString _r = _t->formatTime((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QLocale::FormatType>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<KFormat::TimeFormatOptions>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: { QString _r = _t->formatTime((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QLocale::FormatType>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 11: { QString _r = _t->formatTime((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 12: { QString _r = _t->formatDistance((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KFormat::DistanceFormatOptions>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 13: { QString _r = _t->formatDistance((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *Formats::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Formats::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7FormatsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Formats::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN11FormatTypesE_t {};
} // unnamed namespace

template <> constexpr inline auto FormatTypes::qt_create_metaobjectdata<qt_meta_tag_ZN11FormatTypesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FormatTypes",
        "QML.Element",
        "QML.Foreign",
        "KFormat",
        "QML.ForeignIsNamespace",
        "true"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    0 },
            {    2,    3 },
            {    4,    5 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN11FormatTypesE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN11FormatTypesE =
    FormatTypes::qt_create_metaobjectdata<qt_meta_tag_ZN11FormatTypesE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN11FormatTypesE =
    qt_staticMetaObjectContent_ZN11FormatTypesE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN11FormatTypesE =
    qt_staticMetaObjectContent_ZN11FormatTypesE.relocatingData;

Q_CONSTINIT const QMetaObject FormatTypes::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN11FormatTypesE.stringdata,
    qt_staticMetaObjectStaticContent_ZN11FormatTypesE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN11FormatTypesE.metaTypes,
    nullptr
} };

QT_WARNING_POP
