/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<formats.h>)
#  include <formats.h>
#endif
#if __has_include(<kosreleaseproxy.h>)
#  include <kosreleaseproxy.h>
#endif
#if __has_include(<kuserproxy.h>)
#  include <kuserproxy.h>
#endif
#if __has_include(<sandbox.h>)
#  include <sandbox.h>
#endif
#if __has_include(<types.h>)
#  include <types.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_coreaddons()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    QMetaType::fromType<KFormat>().id();
    qmlRegisterNamespaceAndRevisions(&KFormat::staticMetaObject, "org.kde.coreaddons", 1, nullptr, &FormatTypes::staticMetaObject, nullptr);
    qmlRegisterEnum<KFormat::DurationFormatOptions>("KFormat::DurationFormatOptions");
    qmlRegisterEnum<KFormat::DurationFormatOption>("KFormat::DurationFormatOption");
    qmlRegisterEnum<KFormat::TimeFormatOptions>("KFormat::TimeFormatOptions");
    qmlRegisterEnum<KFormat::TimeFormatOption>("KFormat::TimeFormatOption");
    qmlRegisterEnum<KFormat::DistanceFormatOptions>("KFormat::DistanceFormatOptions");
    qmlRegisterEnum<KFormat::DistanceFormatOption>("KFormat::DistanceFormatOption");
    qmlRegisterTypesAndRevisions<Formats>("org.kde.coreaddons", 1);
    QMetaType::fromType<KAboutData>().id();
    qmlRegisterNamespaceAndRevisions(&KAboutData::staticMetaObject, "org.kde.coreaddons", 1, nullptr, &KAboutDataForeign::staticMetaObject, nullptr);
    qmlRegisterEnum<KAboutData::UrlType>("KAboutData::UrlType");
    qmlRegisterTypesAndRevisions<KAboutReleaseForeign>("org.kde.coreaddons", 1);
    qmlRegisterTypesAndRevisions<KOSReleaseProxy>("org.kde.coreaddons", 1);
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &KTextToHTML::staticMetaObject;},
            "KTextToHTML");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&KTextToHTML::staticMetaObject, "org.kde.coreaddons", 1, nullptr, &KTextToHtmlForeign::staticMetaObject, nullptr);
    qmlRegisterEnum<KTextToHTML::Options>("KTextToHTML::Options");
    qmlRegisterEnum<KTextToHTML::Option>("KTextToHTML::Option");
    qmlRegisterTypesAndRevisions<KUserProxy>("org.kde.coreaddons", 1);
    qmlRegisterTypesAndRevisions<Sandbox>("org.kde.coreaddons", 1);
    qmlRegisterEnum<Sandbox::Type>("Sandbox::Type");
    QT_WARNING_POP
    qmlRegisterModule("org.kde.coreaddons", 1, 0);
}

static const QQmlModuleRegistration orgkdecoreaddonsRegistration("org.kde.coreaddons", qml_register_types_org_kde_coreaddons);
