/****************************************************************************
** Meta object code from reading C++ file 'ktexttohtml.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kcoreaddons-6.29.0/src/lib/text/ktexttohtml.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ktexttohtml.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11KTextToHTMLE_t {};
} // unnamed namespace

template <> constexpr inline auto KTextToHTML::qt_create_metaobjectdata<qt_meta_tag_ZN11KTextToHTMLE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KTextToHTML",
        "Options",
        "Option",
        "PreserveSpaces",
        "ReplaceSmileys",
        "IgnoreUrls",
        "HighlightText",
        "ConvertPhoneNumbers"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // flag 'Options'
        QtMocHelpers::EnumData<Options>(1, 2, QMC::EnumIsFlag).add({
            {    3, Option::PreserveSpaces },
            {    4, Option::ReplaceSmileys },
            {    5, Option::IgnoreUrls },
            {    6, Option::HighlightText },
            {    7, Option::ConvertPhoneNumbers },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN11KTextToHTMLE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN11KTextToHTMLE =
    KTextToHTML::qt_create_metaobjectdata<qt_meta_tag_ZN11KTextToHTMLE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN11KTextToHTMLE =
    qt_staticMetaObjectContent_ZN11KTextToHTMLE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN11KTextToHTMLE =
    qt_staticMetaObjectContent_ZN11KTextToHTMLE.relocatingData;

Q_CONSTINIT const QMetaObject KTextToHTML::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN11KTextToHTMLE.stringdata,
    qt_staticMetaObjectStaticContent_ZN11KTextToHTMLE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN11KTextToHTMLE.metaTypes,
    nullptr
} };

QT_WARNING_POP
