/****************************************************************************
** Meta object code from reading C++ file 'kformat.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kcoreaddons-6.29.0/src/lib/util/kformat.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kformat.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7KFormatE_t {};
} // unnamed namespace

template <> constexpr inline auto KFormat::qt_create_metaobjectdata<qt_meta_tag_ZN7KFormatE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KFormat",
        "DurationFormatOptions",
        "DurationFormatOption",
        "DefaultDuration",
        "InitialDuration",
        "ShowMilliseconds",
        "HideSeconds",
        "FoldHours",
        "AbbreviatedDuration",
        "TimeFormatOptions",
        "TimeFormatOption",
        "DoNotAddTimeZone",
        "AddTimezoneAbbreviation",
        "AddTimezoneAbbreviationIfNeeded",
        "DistanceFormatOptions",
        "DistanceFormatOption",
        "LocaleDistanceUnits",
        "MetricDistanceUnits"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // flag 'DurationFormatOptions'
        QtMocHelpers::EnumData<DurationFormatOptions>(1, 2, QMC::EnumIsFlag).add({
            {    3, DurationFormatOption::DefaultDuration },
            {    4, DurationFormatOption::InitialDuration },
            {    5, DurationFormatOption::ShowMilliseconds },
            {    6, DurationFormatOption::HideSeconds },
            {    7, DurationFormatOption::FoldHours },
            {    8, DurationFormatOption::AbbreviatedDuration },
        }),
        // flag 'TimeFormatOptions'
        QtMocHelpers::EnumData<TimeFormatOptions>(9, 10, QMC::EnumIsFlag).add({
            {   11, TimeFormatOption::DoNotAddTimeZone },
            {   12, TimeFormatOption::AddTimezoneAbbreviation },
            {   13, TimeFormatOption::AddTimezoneAbbreviationIfNeeded },
        }),
        // flag 'DistanceFormatOptions'
        QtMocHelpers::EnumData<DistanceFormatOptions>(14, 15, QMC::EnumIsFlag).add({
            {   16, DistanceFormatOption::LocaleDistanceUnits },
            {   17, DistanceFormatOption::MetricDistanceUnits },
        }),
    };
    return QtMocHelpers::metaObjectData<KFormat, qt_meta_tag_ZN7KFormatE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KFormat::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KFormatE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KFormatE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7KFormatE_t>.metaTypes,
    nullptr
} };

QT_WARNING_POP
