/****************************************************************************
** Meta object code from reading C++ file 'kjob.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kcoreaddons-6.29.0/src/lib/jobs/kjob.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kjob.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4KJobE_t {};
} // unnamed namespace

template <> constexpr inline auto KJob::qt_create_metaobjectdata<qt_meta_tag_ZN4KJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KJob",
        "finished",
        "",
        "KJob*",
        "job",
        "suspended",
        "resumed",
        "result",
        "description",
        "title",
        "std::pair<QString,QString>",
        "field1",
        "field2",
        "infoMessage",
        "message",
        "warning",
        "totalAmountChanged",
        "KJob::Unit",
        "unit",
        "amount",
        "processedAmountChanged",
        "totalSize",
        "size",
        "processedSize",
        "percentChanged",
        "percent",
        "speed",
        "kill",
        "KJob::KillVerbosity",
        "verbosity",
        "suspend",
        "resume",
        "start",
        "processedAmount",
        "Unit",
        "totalAmount",
        "error",
        "errorText",
        "errorString",
        "capabilities",
        "Capabilities",
        "Bytes",
        "Files",
        "Directories",
        "Items",
        "UnitsCount",
        "Capability",
        "NoCapabilities",
        "Killable",
        "Suspendable",
        "KillVerbosity",
        "Quietly",
        "EmitResult"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'finished'
        QtMocHelpers::SignalData<void(KJob *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'suspended'
        QtMocHelpers::SignalData<void(KJob *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'resumed'
        QtMocHelpers::SignalData<void(KJob *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'result'
        QtMocHelpers::SignalData<void(KJob *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'description'
        QtMocHelpers::SignalData<void(KJob *, const QString &, const QPair<QString,QString> &, const QPair<QString,QString> &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 9 }, { 0x80000000 | 10, 11 }, { 0x80000000 | 10, 12 },
        }}),
        // Signal 'description'
        QtMocHelpers::SignalData<void(KJob *, const QString &, const QPair<QString,QString> &)>(8, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 9 }, { 0x80000000 | 10, 11 },
        }}),
        // Signal 'description'
        QtMocHelpers::SignalData<void(KJob *, const QString &)>(8, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 9 },
        }}),
        // Signal 'infoMessage'
        QtMocHelpers::SignalData<void(KJob *, const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 14 },
        }}),
        // Signal 'warning'
        QtMocHelpers::SignalData<void(KJob *, const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 14 },
        }}),
        // Signal 'totalAmountChanged'
        QtMocHelpers::SignalData<void(KJob *, KJob::Unit, qulonglong)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 17, 18 }, { QMetaType::ULongLong, 19 },
        }}),
        // Signal 'processedAmountChanged'
        QtMocHelpers::SignalData<void(KJob *, KJob::Unit, qulonglong)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 17, 18 }, { QMetaType::ULongLong, 19 },
        }}),
        // Signal 'totalSize'
        QtMocHelpers::SignalData<void(KJob *, qulonglong)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::ULongLong, 22 },
        }}),
        // Signal 'processedSize'
        QtMocHelpers::SignalData<void(KJob *, qulonglong)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::ULongLong, 22 },
        }}),
        // Signal 'percentChanged'
        QtMocHelpers::SignalData<void(KJob *, unsigned long)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::ULong, 25 },
        }}),
        // Signal 'speed'
        QtMocHelpers::SignalData<void(KJob *, unsigned long)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::ULong, 26 },
        }}),
        // Slot 'kill'
        QtMocHelpers::SlotData<bool(KJob::KillVerbosity)>(27, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'kill'
        QtMocHelpers::SlotData<bool()>(27, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool),
        // Slot 'suspend'
        QtMocHelpers::SlotData<bool()>(30, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'resume'
        QtMocHelpers::SlotData<bool()>(31, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'start'
        QtMocHelpers::MethodData<void()>(32, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Method 'processedAmount'
        QtMocHelpers::MethodData<qulonglong(enum Unit) const>(33, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::ULongLong, {{
            { 0x80000000 | 34, 18 },
        }}),
        // Method 'totalAmount'
        QtMocHelpers::MethodData<qulonglong(enum Unit) const>(35, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::ULongLong, {{
            { 0x80000000 | 34, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'error'
        QtMocHelpers::PropertyData<int>(36, QMetaType::Int, QMC::DefaultPropertyFlags, 3),
        // property 'errorText'
        QtMocHelpers::PropertyData<QString>(37, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'errorString'
        QtMocHelpers::PropertyData<QString>(38, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'percent'
        QtMocHelpers::PropertyData<ulong>(25, QMetaType::ULong, QMC::DefaultPropertyFlags, 13),
        // property 'capabilities'
        QtMocHelpers::PropertyData<Capabilities>(39, 0x80000000 | 40, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Unit'
        QtMocHelpers::EnumData<enum Unit>(34, 34, QMC::EnumFlags{}).add({
            {   41, Unit::Bytes },
            {   42, Unit::Files },
            {   43, Unit::Directories },
            {   44, Unit::Items },
            {   45, Unit::UnitsCount },
        }),
        // enum 'Capability'
        QtMocHelpers::EnumData<enum Capability>(46, 46, QMC::EnumFlags{}).add({
            {   47, Capability::NoCapabilities },
            {   48, Capability::Killable },
            {   49, Capability::Suspendable },
        }),
        // flag 'Capabilities'
        QtMocHelpers::EnumData<Capabilities>(40, 46, QMC::EnumIsFlag).add({
            {   47, Capability::NoCapabilities },
            {   48, Capability::Killable },
            {   49, Capability::Suspendable },
        }),
        // enum 'KillVerbosity'
        QtMocHelpers::EnumData<enum KillVerbosity>(50, 50, QMC::EnumFlags{}).add({
            {   51, KillVerbosity::Quietly },
            {   52, KillVerbosity::EmitResult },
        }),
    };
    return QtMocHelpers::metaObjectData<KJob, qt_meta_tag_ZN4KJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KJob::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4KJobE_t>.metaTypes,
    nullptr
} };

void KJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->finished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1])), QPrivateSignal()); break;
        case 1: _t->suspended((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1])), QPrivateSignal()); break;
        case 2: _t->resumed((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1])), QPrivateSignal()); break;
        case 3: _t->result((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1])), QPrivateSignal()); break;
        case 4: _t->description((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<std::pair<QString,QString>>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<std::pair<QString,QString>>>(_a[4]))); break;
        case 5: _t->description((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<std::pair<QString,QString>>>(_a[3]))); break;
        case 6: _t->description((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->infoMessage((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 8: _t->warning((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 9: _t->totalAmountChanged((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KJob::Unit>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[3])), QPrivateSignal()); break;
        case 10: _t->processedAmountChanged((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KJob::Unit>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[3])), QPrivateSignal()); break;
        case 11: _t->totalSize((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2]))); break;
        case 12: _t->processedSize((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2]))); break;
        case 13: _t->percentChanged((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[2])), QPrivateSignal()); break;
        case 14: _t->speed((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[2]))); break;
        case 15: { bool _r = _t->kill((*reinterpret_cast<std::add_pointer_t<KJob::KillVerbosity>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->kill();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->suspend();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: { bool _r = _t->resume();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->start(); break;
        case 20: { qulonglong _r = _t->processedAmount((*reinterpret_cast<std::add_pointer_t<enum Unit>>(_a[1])));
            if (_a[0]) *reinterpret_cast<qulonglong*>(_a[0]) = std::move(_r); }  break;
        case 21: { qulonglong _r = _t->totalAmount((*reinterpret_cast<std::add_pointer_t<enum Unit>>(_a[1])));
            if (_a[0]) *reinterpret_cast<qulonglong*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KJob::*)(KJob * , QPrivateSignal)>(_a, &KJob::finished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KJob::*)(KJob * , QPrivateSignal)>(_a, &KJob::suspended, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KJob::*)(KJob * , QPrivateSignal)>(_a, &KJob::resumed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KJob::*)(KJob * , QPrivateSignal)>(_a, &KJob::result, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KJob::*)(KJob * , const QString & , const QPair<QString,QString> & , const QPair<QString,QString> & )>(_a, &KJob::description, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KJob::*)(KJob * , const QString & )>(_a, &KJob::infoMessage, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (KJob::*)(KJob * , const QString & )>(_a, &KJob::warning, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (KJob::*)(KJob * , KJob::Unit , qulonglong , QPrivateSignal)>(_a, &KJob::totalAmountChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (KJob::*)(KJob * , KJob::Unit , qulonglong , QPrivateSignal)>(_a, &KJob::processedAmountChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (KJob::*)(KJob * , qulonglong )>(_a, &KJob::totalSize, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (KJob::*)(KJob * , qulonglong )>(_a, &KJob::processedSize, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (KJob::*)(KJob * , unsigned long , QPrivateSignal)>(_a, &KJob::percentChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (KJob::*)(KJob * , unsigned long )>(_a, &KJob::speed, 14))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->error(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->errorText(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->errorString(); break;
        case 3: *reinterpret_cast<ulong*>(_v) = _t->percent(); break;
        case 4: QtMocHelpers::assignFlags<Capabilities>(_v, _t->capabilities()); break;
        default: break;
        }
    }
}

const QMetaObject *KJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4KJobE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void KJob::finished(KJob * _t1, QPrivateSignal _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void KJob::suspended(KJob * _t1, QPrivateSignal _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void KJob::resumed(KJob * _t1, QPrivateSignal _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void KJob::result(KJob * _t1, QPrivateSignal _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void KJob::description(KJob * _t1, const QString & _t2, const QPair<QString,QString> & _t3, const QPair<QString,QString> & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 7
void KJob::infoMessage(KJob * _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void KJob::warning(KJob * _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void KJob::totalAmountChanged(KJob * _t1, KJob::Unit _t2, qulonglong _t3, QPrivateSignal _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 10
void KJob::processedAmountChanged(KJob * _t1, KJob::Unit _t2, qulonglong _t3, QPrivateSignal _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 11
void KJob::totalSize(KJob * _t1, qulonglong _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2);
}

// SIGNAL 12
void KJob::processedSize(KJob * _t1, qulonglong _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2);
}

// SIGNAL 13
void KJob::percentChanged(KJob * _t1, unsigned long _t2, QPrivateSignal _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2, _t3);
}

// SIGNAL 14
void KJob::speed(KJob * _t1, unsigned long _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2);
}
QT_WARNING_POP
