/****************************************************************************
** Meta object code from reading C++ file 'kpluginmetadata.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kcoreaddons-6.29.0/src/lib/plugin/kpluginmetadata.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kpluginmetadata.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15KPluginMetaDataE_t {};
} // unnamed namespace

template <> constexpr inline auto KPluginMetaData::qt_create_metaobjectdata<qt_meta_tag_ZN15KPluginMetaDataE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPluginMetaData",
        "isValid",
        "isHidden",
        "fileName",
        "rawData",
        "QJsonObject",
        "name",
        "description",
        "authors",
        "QList<KAboutPerson>",
        "translators",
        "otherContributors",
        "category",
        "iconName",
        "license",
        "licenseText",
        "copyrightText",
        "pluginId",
        "version",
        "website",
        "bugReportUrl",
        "mimeTypes",
        "formFactors",
        "isEnabledByDefault",
        "KPluginMetaDataOption",
        "AllowEmptyMetaData",
        "CacheMetaData"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'isValid'
        QtMocHelpers::PropertyData<bool>(1, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'isHidden'
        QtMocHelpers::PropertyData<bool>(2, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fileName'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'rawData'
        QtMocHelpers::PropertyData<QJsonObject>(4, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'description'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'authors'
        QtMocHelpers::PropertyData<QList<KAboutPerson>>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'translators'
        QtMocHelpers::PropertyData<QList<KAboutPerson>>(10, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'otherContributors'
        QtMocHelpers::PropertyData<QList<KAboutPerson>>(11, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'category'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'iconName'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'license'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'licenseText'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'copyrightText'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pluginId'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'version'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'website'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bugReportUrl'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mimeTypes'
        QtMocHelpers::PropertyData<QStringList>(21, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'formFactors'
        QtMocHelpers::PropertyData<QStringList>(22, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'isEnabledByDefault'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'KPluginMetaDataOption'
        QtMocHelpers::EnumData<enum KPluginMetaDataOption>(24, 24, QMC::EnumFlags{}).add({
            {   25, KPluginMetaDataOption::AllowEmptyMetaData },
            {   26, KPluginMetaDataOption::CacheMetaData },
        }),
    };
    return QtMocHelpers::metaObjectData<KPluginMetaData, qt_meta_tag_ZN15KPluginMetaDataE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KPluginMetaData::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KPluginMetaDataE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KPluginMetaDataE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15KPluginMetaDataE_t>.metaTypes,
    nullptr
} };

void KPluginMetaData::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<KPluginMetaData *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isValid(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isHidden(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->fileName(); break;
        case 3: *reinterpret_cast<QJsonObject*>(_v) = _t->rawData(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->description(); break;
        case 6: *reinterpret_cast<QList<KAboutPerson>*>(_v) = _t->authors(); break;
        case 7: *reinterpret_cast<QList<KAboutPerson>*>(_v) = _t->translators(); break;
        case 8: *reinterpret_cast<QList<KAboutPerson>*>(_v) = _t->otherContributors(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->category(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->iconName(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->license(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->licenseText(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->copyrightText(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->pluginId(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->version(); break;
        case 16: *reinterpret_cast<QString*>(_v) = _t->website(); break;
        case 17: *reinterpret_cast<QString*>(_v) = _t->bugReportUrl(); break;
        case 18: *reinterpret_cast<QStringList*>(_v) = _t->mimeTypes(); break;
        case 19: *reinterpret_cast<QStringList*>(_v) = _t->formFactors(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->isEnabledByDefault(); break;
        default: break;
        }
    }
}
QT_WARNING_POP
