/****************************************************************************
** Meta object code from reading C++ file 'kaboutdata.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kcoreaddons-6.29.0/src/lib/kaboutdata.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kaboutdata.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12KAboutPersonE_t {};
} // unnamed namespace

template <> constexpr inline auto KAboutPerson::qt_create_metaobjectdata<qt_meta_tag_ZN12KAboutPersonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KAboutPerson",
        "name",
        "task",
        "emailAddress",
        "webAddress",
        "avatarUrl",
        "QUrl"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'task'
        QtMocHelpers::PropertyData<QString>(2, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'emailAddress'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'webAddress'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'avatarUrl'
        QtMocHelpers::PropertyData<QUrl>(5, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KAboutPerson, qt_meta_tag_ZN12KAboutPersonE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KAboutPerson::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KAboutPersonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KAboutPersonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12KAboutPersonE_t>.metaTypes,
    nullptr
} };

void KAboutPerson::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<KAboutPerson *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->task(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->emailAddress(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->webAddress(); break;
        case 4: *reinterpret_cast<QUrl*>(_v) = _t->avatarUrl(); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN13KAboutLicenseE_t {};
} // unnamed namespace

template <> constexpr inline auto KAboutLicense::qt_create_metaobjectdata<qt_meta_tag_ZN13KAboutLicenseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KAboutLicense",
        "name",
        "text",
        "key",
        "KAboutLicense::LicenseKey",
        "spdx",
        "LicenseKey",
        "Custom",
        "File",
        "Unknown",
        "GPL",
        "GPL_V2",
        "LGPL",
        "LGPL_V2",
        "BSDL",
        "BSD_2_Clause",
        "Artistic",
        "GPL_V3",
        "LGPL_V3",
        "LGPL_V2_1",
        "MIT",
        "ODbL_V1",
        "Apache_V2",
        "FTL",
        "BSL_V1",
        "BSD_3_Clause",
        "CC0_V1",
        "MPL_V2",
        "NameFormat",
        "ShortName",
        "FullName",
        "VersionRestriction",
        "OnlyThisVersion",
        "OrLaterVersions"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'text'
        QtMocHelpers::PropertyData<QString>(2, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'key'
        QtMocHelpers::PropertyData<KAboutLicense::LicenseKey>(3, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'spdx'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'LicenseKey'
        QtMocHelpers::EnumData<enum LicenseKey>(6, 6, QMC::EnumFlags{}).add({
            {    7, LicenseKey::Custom },
            {    8, LicenseKey::File },
            {    9, LicenseKey::Unknown },
            {   10, LicenseKey::GPL },
            {   11, LicenseKey::GPL_V2 },
            {   12, LicenseKey::LGPL },
            {   13, LicenseKey::LGPL_V2 },
            {   14, LicenseKey::BSDL },
            {   15, LicenseKey::BSD_2_Clause },
            {   16, LicenseKey::Artistic },
            {   17, LicenseKey::GPL_V3 },
            {   18, LicenseKey::LGPL_V3 },
            {   19, LicenseKey::LGPL_V2_1 },
            {   20, LicenseKey::MIT },
            {   21, LicenseKey::ODbL_V1 },
            {   22, LicenseKey::Apache_V2 },
            {   23, LicenseKey::FTL },
            {   24, LicenseKey::BSL_V1 },
            {   25, LicenseKey::BSD_3_Clause },
            {   26, LicenseKey::CC0_V1 },
            {   27, LicenseKey::MPL_V2 },
        }),
        // enum 'NameFormat'
        QtMocHelpers::EnumData<enum NameFormat>(28, 28, QMC::EnumFlags{}).add({
            {   29, NameFormat::ShortName },
            {   30, NameFormat::FullName },
        }),
        // enum 'VersionRestriction'
        QtMocHelpers::EnumData<enum VersionRestriction>(31, 31, QMC::EnumFlags{}).add({
            {   32, VersionRestriction::OnlyThisVersion },
            {   33, VersionRestriction::OrLaterVersions },
        }),
    };
    return QtMocHelpers::metaObjectData<KAboutLicense, qt_meta_tag_ZN13KAboutLicenseE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KAboutLicense::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KAboutLicenseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KAboutLicenseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KAboutLicenseE_t>.metaTypes,
    nullptr
} };

void KAboutLicense::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<KAboutLicense *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->text(); break;
        case 2: *reinterpret_cast<KAboutLicense::LicenseKey*>(_v) = _t->key(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->spdx(); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN15KAboutComponentE_t {};
} // unnamed namespace

template <> constexpr inline auto KAboutComponent::qt_create_metaobjectdata<qt_meta_tag_ZN15KAboutComponentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KAboutComponent",
        "name",
        "description",
        "webAddress",
        "licenses",
        "KAboutLicense",
        "version"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'description'
        QtMocHelpers::PropertyData<QString>(2, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'webAddress'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'licenses'
        QtMocHelpers::PropertyData<KAboutLicense>(4, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'version'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KAboutComponent, qt_meta_tag_ZN15KAboutComponentE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KAboutComponent::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KAboutComponentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15KAboutComponentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15KAboutComponentE_t>.metaTypes,
    nullptr
} };

void KAboutComponent::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<KAboutComponent *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->description(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->webAddress(); break;
        case 3: *reinterpret_cast<KAboutLicense*>(_v) = _t->license(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->version(); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN13KAboutReleaseE_t {};
} // unnamed namespace

template <> constexpr inline auto KAboutRelease::qt_create_metaobjectdata<qt_meta_tag_ZN13KAboutReleaseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KAboutRelease",
        "version",
        "date",
        "description",
        "url",
        "QUrl"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'version'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'date'
        QtMocHelpers::PropertyData<QDate>(2, QMetaType::QDate, QMC::DefaultPropertyFlags),
        // property 'description'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'url'
        QtMocHelpers::PropertyData<QUrl>(4, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KAboutRelease, qt_meta_tag_ZN13KAboutReleaseE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KAboutRelease::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KAboutReleaseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KAboutReleaseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KAboutReleaseE_t>.metaTypes,
    nullptr
} };

void KAboutRelease::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<KAboutRelease *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->version(); break;
        case 1: *reinterpret_cast<QDate*>(_v) = _t->date(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->description(); break;
        case 3: *reinterpret_cast<QUrl*>(_v) = _t->url(); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN10KAboutDataE_t {};
} // unnamed namespace

template <> constexpr inline auto KAboutData::qt_create_metaobjectdata<qt_meta_tag_ZN10KAboutDataE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KAboutData",
        "url",
        "",
        "KAboutData::UrlType",
        "type",
        "displayName",
        "productName",
        "componentName",
        "programLogo",
        "QVariant",
        "shortDescription",
        "homepage",
        "bugAddress",
        "version",
        "otherText",
        "authors",
        "QList<KAboutPerson>",
        "credits",
        "translators",
        "components",
        "QList<KAboutComponent>",
        "licenses",
        "QList<KAboutLicense>",
        "copyrightStatement",
        "desktopFileName",
        "releases",
        "QList<KAboutRelease>",
        "UrlType",
        "Homepage",
        "Bugtracker",
        "Faq",
        "Help",
        "Donation",
        "Translate",
        "Contact",
        "VCSBrowser",
        "Contribute",
        "XKDEMatrixRoom",
        "XKDEForum",
        "XKDEMastodon"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'url'
        QtMocHelpers::MethodData<QString(KAboutData::UrlType) const>(1, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'displayName'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'productName'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'componentName'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'programLogo'
        QtMocHelpers::PropertyData<QVariant>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'shortDescription'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'homepage'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bugAddress'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'version'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'otherText'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'authors'
        QtMocHelpers::PropertyData<QList<KAboutPerson>>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'credits'
        QtMocHelpers::PropertyData<QList<KAboutPerson>>(17, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'translators'
        QtMocHelpers::PropertyData<QList<KAboutPerson>>(18, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'components'
        QtMocHelpers::PropertyData<QList<KAboutComponent>>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'licenses'
        QtMocHelpers::PropertyData<QList<KAboutLicense>>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'copyrightStatement'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'desktopFileName'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'releases'
        QtMocHelpers::PropertyData<QList<KAboutRelease>>(25, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'UrlType'
        QtMocHelpers::EnumData<enum UrlType>(27, 27, QMC::EnumFlags{}).add({
            {   28, UrlType::Homepage },
            {   29, UrlType::Bugtracker },
            {   30, UrlType::Faq },
            {   31, UrlType::Help },
            {   32, UrlType::Donation },
            {   33, UrlType::Translate },
            {   34, UrlType::Contact },
            {   35, UrlType::VCSBrowser },
            {   36, UrlType::Contribute },
            {   37, UrlType::XKDEMatrixRoom },
            {   38, UrlType::XKDEForum },
            {   39, UrlType::XKDEMastodon },
        }),
    };
    return QtMocHelpers::metaObjectData<KAboutData, qt_meta_tag_ZN10KAboutDataE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KAboutData::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KAboutDataE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KAboutDataE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10KAboutDataE_t>.metaTypes,
    nullptr
} };

void KAboutData::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<KAboutData *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->url((*reinterpret_cast<std::add_pointer_t<KAboutData::UrlType>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->displayName(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->productName(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->componentName(); break;
        case 3: *reinterpret_cast<QVariant*>(_v) = _t->programLogo(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->shortDescription(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->homepage(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->bugAddress(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->version(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->otherText(); break;
        case 9: *reinterpret_cast<QList<KAboutPerson>*>(_v) = _t->authors(); break;
        case 10: *reinterpret_cast<QList<KAboutPerson>*>(_v) = _t->credits(); break;
        case 11: *reinterpret_cast<QList<KAboutPerson>*>(_v) = _t->translators(); break;
        case 12: *reinterpret_cast<QList<KAboutComponent>*>(_v) = _t->components(); break;
        case 13: *reinterpret_cast<QList<KAboutLicense>*>(_v) = _t->licenses(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->copyrightStatement(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->desktopFileName(); break;
        case 16: *reinterpret_cast<QList<KAboutRelease>*>(_v) = _t->releases(); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN18KAboutDataListenerE_t {};
} // unnamed namespace

template <> constexpr inline auto KAboutDataListener::qt_create_metaobjectdata<qt_meta_tag_ZN18KAboutDataListenerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KAboutDataListener",
        "applicationDataChanged",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'applicationDataChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KAboutDataListener, qt_meta_tag_ZN18KAboutDataListenerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KAboutDataListener::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18KAboutDataListenerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18KAboutDataListenerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18KAboutDataListenerE_t>.metaTypes,
    nullptr
} };

void KAboutDataListener::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KAboutDataListener *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->applicationDataChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KAboutDataListener::*)()>(_a, &KAboutDataListener::applicationDataChanged, 0))
            return;
    }
}

const QMetaObject *KAboutDataListener::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KAboutDataListener::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18KAboutDataListenerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KAboutDataListener::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void KAboutDataListener::applicationDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
